@@ -17,10 +17,10 @@ extensions = [
 source_suffix = '.rst'
 master_doc = 'index'
 project = 'Holdup'
-year = '2016-2019'
+year = '2016-2022'
 author = 'Ionel Cristian Mărieș'
 copyright = '{0}, {1}'.format(year, author)
-version = release = '1.8.1'
+version = release = '3.0.0'
 
 pygments_style = 'trac'
 templates_path = ['.']
@@ -31,14 +31,14 @@ extlinks = {
 html_theme = "sphinx_py3doc_enhanced_theme"
 html_theme_path = [sphinx_py3doc_enhanced_theme.get_html_theme_path()]
 html_theme_options = {
-    'githuburl': 'https://github.com/ionelmc/python-holdup/'
+    'githuburl': 'https://github.com/ionelmc/python-holdup/',
 }
 
 html_use_smartypants = True
 html_last_updated_fmt = '%b %d, %Y'
 html_split_index = False
 html_sidebars = {
-   '**': ['searchbox.html', 'globaltoc.html', 'sourcelink.html'],
+    '**': ['searchbox.html', 'globaltoc.html', 'sourcelink.html'],
 }
 html_short_title = '%s-%s' % (project, version)
 
